@@ -1,11 +1,11 @@
 use strict;
 use warnings;
-package Dist::Zilla::Plugin::Git::Contributors; # git description: v0.031-2-gf4f7111
+package Dist::Zilla::Plugin::Git::Contributors; # git description: v0.032-9-g2554cad
 # vim: set ts=8 sts=4 sw=4 tw=115 et :
 # ABSTRACT: Add contributor names from git to your distribution
 # KEYWORDS: plugin distribution metadata git contributors authors commits
 
-our $VERSION = '0.032';
+our $VERSION = '0.033';
 
 use Moose;
 with 'Dist::Zilla::Role::MetaProvider',
@@ -66,10 +66,7 @@ around dump_config => sub
         include_authors => $self->include_authors ? 1 : 0,
         include_releaser  => $self->include_releaser ? 1 : 0,
         order_by => $self->order_by,
-        paths => [ sort map {
-                     my $p = path($_)->realpath;
-                     ($dist_root->subsumes($p) ? $p->relative($dist_root) : $p)->stringify
-                   } $self->paths ],
+        paths => [ sort $self->paths ],
         $self->remove ? ( remove => '...' ) : (),
         git_version => $self->_git('version'),
         blessed($self) ne __PACKAGE__ ? ( version => $VERSION ) : (),
@@ -267,7 +264,7 @@ Dist::Zilla::Plugin::Git::Contributors - Add contributor names from git to your
 
 =head1 VERSION
 
-version 0.032
+version 0.033
 
 =head1 SYNOPSIS
 
@@ -378,10 +375,6 @@ L<Dist::Zilla::Plugin::Meta::Contributors> - adds an explicit list of names to x
 
 =item *
 
-L<Dist::Zilla::Plugin::ContributorsFile> - takes a list of names from a file
-
-=item *
-
 L<Dist::Zilla::Plugin::ContributorsFromGit> - more dependencies, problematic tests, passes around a lot of extra data in stashes unnecessarily
 
 =item *
@@ -392,6 +385,10 @@ L<Dist::Zilla::Plugin::ContributorsFromPod> - takes the list of contributors fro
 
 L<Module::Install::Contributors>
 
+=item *
+
+L<Dist::Zilla::Plugin::ContributorsFile> - adds CONTRIBUTORS file, containing names from x_contributors metadata
+
 =back
 
 =for Pod::Coverage mvp_multivalue_args mvp_aliases metadata register_prereqs
